==> kjy-livecenter-api-0.1.45-sources.jar: cn/com/duiba/kjy/livecenter/api/remoteservice/RemoteLiveAgentService.java <==
package cn.com.duiba.kjy.livecenter.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.livecenter.api.dto.CenterPageResult;
import cn.com.duiba.kjy.livecenter.api.dto.agent.LiveAgentAdviceInfoApiDto;
import cn.com.duiba.kjy.livecenter.api.dto.agent.LiveAgentInfoApiDto;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveAgentCompanyTeamDto;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveAgentDto;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveAgentUserDto;
import cn.com.duiba.kjy.livecenter.api.dto.user.LiveAgentCompanyDto;
import cn.com.duiba.kjy.livecenter.api.param.company.LiveAgentSearchParam;
import cn.com.duiba.kjy.livecenter.api.param.liveagent.EsLiveAgentSearchParam;
import cn.com.duiba.kjy.livecenter.api.param.liveagent.LiveAgentPageQueryParam;
import cn.com.duiba.kjy.livecenter.api.param.user.AgentUpdate4KjjParam;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 直播代理人rpc服务类
 * @author 吴文哲
 * @date 2020-03-30 21:00
 **/
@AdvancedFeignClient
public interface RemoteLiveAgentService {


    /**
     * 根据id查询
     * @param id 主键id
     * @return 直播公司团队
     */
    LiveAgentDto findById(Long id);

    /**
     * 根据主键id查找列表
     * @param ids
     * @return
     */
    List<LiveAgentDto> findByIds(List<Long> ids);

    /**
     * 根据团队id 统计
     * @param teamId
     * @return
     */
    Integer countByTeamId(Long teamId);

    /**
     * 将代理人从团队中移除
     * @return
     */
    Integer removeAgentFromTeam(Long agentId,Long teamId);

    /**
     * 退出公司
     *
     * @param agentId 代理人id
     * @param companyId 公司id
     * @return true-成功 false-失败
     */
    boolean removeAgentFromCompany(Long agentId, Long companyId);

    /**
     * 代理人批量退出公司
     *
     * @param agentIds 代理人id集合
     * @param companyId 公司id
     * @return 执行结果
     */
    int batchRemoveAgentFromCompany(List<Long> agentIds, Long companyId);

    /**
     * 切换公司及团队
     *
     * @param dto 代理人公司团队信息
     * @return true-切换成功 false-切换失败
     */
    boolean changeCompanyAndTeam(LiveAgentCompanyTeamDto dto);

    /**
     * 根据团队id 查找直播代理人列表
     * @param teamId
     * @return
     */
    List<LiveAgentDto> findByTeamId(Long teamId);

    /**
     * 从缓存中获取代理人的公司id
     * @param agentId
     * @return
     */
    Long getCompanyIdByAgentIdFromCache(Long agentId);

    /**
     * 根据直播用户id 查找代理人信息
     * @param liveUserId
     * @return
     */
    LiveAgentDto findByLiveUserId(Long liveUserId);

    /**
     * 根据直播用户id列表 查找代理人信息列表
     * @param liveUserIds
     * @return 直播代理人信息列表
     */
    List<LiveAgentDto> findByLiveUserIds(List<Long> liveUserIds);

    /**
     * 批量查询公司ID
     * @param liveUserIdList 直播用户ID
     * @return 代理人公司ID集合
     */
    List<LiveAgentCompanyDto> findCompanyByLiveUserIds(List<Long> liveUserIdList);

    /**
     * 分页查询
     * @param param
     * @return
     */
    List<LiveAgentDto> findListByCondition(LiveAgentPageQueryParam param);

    /**
     * 判断是否是当前公司代理人
     * @param liveUserId
     * @param companyId
     * @return true是 false否
     */
    boolean isCurrentCompanyAgent(long liveUserId, long companyId);

    /**
     * 更新代理人客集集系统参数
     * @param param
     * @return
     */
    Integer updateAgent4Kjj(AgentUpdate4KjjParam param);

    /**
     * 批量更新代理人昵称
     *
     * @param params 待更新的参数
     * @return 执行结果
     */
    int batchUpdateNickname(List<AgentUpdate4KjjParam> params);

    /**
     * 查询公司所有代理人
     * @param companyId 公司ID
     * @return key：代理人用户ID，value：代理人ID
     */
    Map<Long, Long> findByCompanyIdCache(Long companyId);

    /**
     * 根据条件,查询记录的总记录数
     * @param param 查询条件
     * @return 符合条件的记录数
     */
    Long selectCount(LiveAgentSearchParam param);

    /**
     * 根据条件查询，分页
     * @param queryParam 查询条件
     * @return 直播公司代理人集合
     */
    List<LiveAgentDto> selectPage(LiveAgentSearchParam queryParam);

    /**
     * 根据公司id统计公司下团队人数
     * @return
     */
    Map<Long,Integer> countByCompanyIdList();

    /**
     * 根据公司id统计代理人人数
     * @param companyId
     * @return
     */
    Integer countByCompanyId(Long companyId);

    /**
     * 搜索代理人用户信息
     *
     * @param param 搜索参数
     * @return 代理人用户信息
     */
    CenterPageResult<LiveAgentUserDto> search(EsLiveAgentSearchParam param);



    /**
     * 根据主键获取代理人信息（包含公司和团队信息）
     * @param id 主键
     * @return 代理人信息
     */
    LiveAgentInfoApiDto findInfoByIdV2(Long id);

    /**
     * 批量查询代理人信息（包含公司和团队信息）
     * @param ids 主键集合
     * @return 代理人信息
     */
    List<LiveAgentInfoApiDto> findInfoByIdsV2(List<Long> ids);


    /**
     * 批量查询代理人信息（用于业务咨询）
     * @param ids 主键集合
     * @return 代理人信息
     */
    List<LiveAgentAdviceInfoApiDto> findAdviceInfoByIdsV2(List<Long> ids);

    /**
     * 根据直播用户id获取代理人id
     * @param liveUserIds 直播用户id集合
     * @return key：直播用户id value：直播代理人id
     */
    Map<Long, Long> getAgentIdByLiveUserIds(Set<Long> liveUserIds);

    /**
     * 更新代理人昵称和头像(用于管理后台，人工同步昵称头像)
     * @param id 代理人ID
     * @param agentName 代理人昵称(客集集名片昵称)
     * @param nickname 用户昵称（客集集用户昵称）
     * @param avatar 头像（客集集用户头像）
     * @return 执行结果
     */
    int updateNameAvatar(Long id, String agentName, String nickname, String avatar);

    /**
     * 根据手机号批量查询代理人id
     *
     * @param phoneNumbers 手机号集合
     * @return key: 手机号 value: agentId
     */
    Map<String, LiveAgentDto> getPhoneAgentMapByPhoneNumbers(List<String> phoneNumbers);
}

==> kjy-livecenter-api-0.1.66-sources.jar: cn/com/duiba/kjy/livecenter/api/remoteservice/RemoteLiveAgentService.java <==
package cn.com.duiba.kjy.livecenter.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.livecenter.api.dto.CenterPageResult;
import cn.com.duiba.kjy.livecenter.api.dto.agent.LiveAgentAdviceInfoApiDto;
import cn.com.duiba.kjy.livecenter.api.dto.agent.LiveAgentInfoApiDto;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveAgentCompanyTeamDto;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveAgentDto;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveAgentUserDto;
import cn.com.duiba.kjy.livecenter.api.dto.user.LiveAgentCompanyDto;
import cn.com.duiba.kjy.livecenter.api.param.agent.LiveAgentInfoUpdateParam;
import cn.com.duiba.kjy.livecenter.api.param.company.LiveAgentSearchParam;
import cn.com.duiba.kjy.livecenter.api.param.liveagent.EsLiveAgentSearchParam;
import cn.com.duiba.kjy.livecenter.api.param.liveagent.LiveAgentPageQueryParam;
import cn.com.duiba.kjy.livecenter.api.param.user.AgentUpdate4KjjParam;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 直播代理人rpc服务类
 * @author 吴文哲
 * @date 2020-03-30 21:00
 **/
@AdvancedFeignClient
public interface RemoteLiveAgentService {


    /**
     * 根据id查询
     * @param id 主键id
     * @return 直播公司团队
     */
    LiveAgentDto findById(Long id);

    /**
     * 根据主键id查找列表
     * @param ids
     * @return
     */
    List<LiveAgentDto> findByIds(List<Long> ids);

    /**
     * 根据团队id 统计
     * @param teamId
     * @return
     */
    Integer countByTeamId(Long teamId);

    /**
     * 将代理人从团队中移除
     * @return
     */
    Integer removeAgentFromTeam(Long agentId,Long teamId);

    /**
     * 退出公司
     *
     * @param agentId 代理人id
     * @param companyId 公司id
     * @return true-成功 false-失败
     */
    boolean removeAgentFromCompany(Long agentId, Long companyId);

    /**
     * 代理人批量退出公司
     *
     * @param agentIds 代理人id集合
     * @param companyId 公司id
     * @return 执行结果
     */
    int batchRemoveAgentFromCompany(List<Long> agentIds, Long companyId);

    /**
     * 切换公司及团队
     *
     * @param dto 代理人公司团队信息
     * @return true-切换成功 false-切换失败
     */
    boolean changeCompanyAndTeam(LiveAgentCompanyTeamDto dto);

    /**
     * 根据团队id 查找直播代理人列表
     * @param teamId
     * @return
     */
    List<LiveAgentDto> findByTeamId(Long teamId);

    /**
     * 从缓存中获取代理人的公司id
     * @param agentId
     * @return
     */
    Long getCompanyIdByAgentIdFromCache(Long agentId);

    /**
     * 根据直播用户id 查找代理人信息
     * @param liveUserId
     * @return
     */
    LiveAgentDto findByLiveUserId(Long liveUserId);

    /**
     * 根据直播用户id列表 查找代理人信息列表
     * @param liveUserIds
     * @return 直播代理人信息列表
     */
    List<LiveAgentDto> findByLiveUserIds(List<Long> liveUserIds);

    /**
     * 批量查询公司ID
     * @param liveUserIdList 直播用户ID
     * @return 代理人公司ID集合
     */
    List<LiveAgentCompanyDto> findCompanyByLiveUserIds(List<Long> liveUserIdList);

    /**
     * 分页查询
     * @param param
     * @return
     */
    List<LiveAgentDto> findListByCondition(LiveAgentPageQueryParam param);

    /**
     * 判断是否是当前公司代理人
     * @param liveUserId
     * @param companyId
     * @return true是 false否
     */
    boolean isCurrentCompanyAgent(long liveUserId, long companyId);

    /**
     * 更新代理人客集集系统参数
     * @param param
     * @return
     */
    Integer updateAgent4Kjj(AgentUpdate4KjjParam param);

    /**
     * 批量更新代理人昵称
     *
     * @param params 待更新的参数
     * @return 执行结果
     */
    int batchUpdateNickname(List<AgentUpdate4KjjParam> params);

    /**
     * 查询公司所有代理人
     * @param companyId 公司ID
     * @return key：代理人用户ID，value：代理人ID
     */
    Map<Long, Long> findByCompanyIdCache(Long companyId);

    /**
     * 根据条件,查询记录的总记录数
     * @param param 查询条件
     * @return 符合条件的记录数
     */
    Long selectCount(LiveAgentSearchParam param);

    /**
     * 根据条件查询，分页
     * @param queryParam 查询条件
     * @return 直播公司代理人集合
     */
    List<LiveAgentDto> selectPage(LiveAgentSearchParam queryParam);

    /**
     * 根据公司id统计公司下团队人数
     * @return
     */
    Map<Long,Integer> countByCompanyIdList();

    /**
     * 根据公司id统计代理人人数
     * @param companyId
     * @return
     */
    Integer countByCompanyId(Long companyId);

    /**
     * 搜索代理人用户信息
     *
     * @param param 搜索参数
     * @return 代理人用户信息
     */
    CenterPageResult<LiveAgentUserDto> search(EsLiveAgentSearchParam param);



    /**
     * 根据主键获取代理人信息（包含公司和团队信息）
     * @param id 主键
     * @return 代理人信息
     */
    LiveAgentInfoApiDto findInfoByIdV2(Long id);

    /**
     * 批量查询代理人信息（包含公司和团队信息）
     * @param ids 主键集合
     * @return 代理人信息
     */
    List<LiveAgentInfoApiDto> findInfoByIdsV2(List<Long> ids);


    /**
     * 批量查询代理人信息（用于业务咨询）
     * @param ids 主键集合
     * @return 代理人信息
     */
    List<LiveAgentAdviceInfoApiDto> findAdviceInfoByIdsV2(List<Long> ids);

    /**
     * 根据直播用户id获取代理人id
     * @param liveUserIds 直播用户id集合
     * @return key：直播用户id value：直播代理人id
     */
    Map<Long, Long> getAgentIdByLiveUserIds(Set<Long> liveUserIds);

    /**
     * 更新代理人昵称和头像(用于管理后台，人工同步昵称头像)
     * @param id 代理人ID
     * @param agentName 代理人昵称(客集集名片昵称)
     * @param nickname 用户昵称（客集集用户昵称）
     * @param avatar 头像（客集集用户头像）
     * @return 执行结果
     */
    int updateNameAvatar(Long id, String agentName, String nickname, String avatar);

    /**
     * 根据手机号批量查询代理人id
     *
     * @param phoneNumbers 手机号集合
     * @return key: 手机号 value: agentId
     */
    Map<String, LiveAgentDto> getPhoneAgentMapByPhoneNumbers(List<String> phoneNumbers);

    /**
     * 根据工号和公司id查询代理人
     *
     * @param jobNumbers 工号
     * @param companyId 公司id
     * @return key: 工号 value: 代理人集合（代理人工号可以重复）
     */
    Map<String, List<LiveAgentDto>> getMapByJobNumbersAndCompanyId(List<String> jobNumbers, Long companyId);

    /**
     * 更新代理人信息
     *
     * @param param 更新参数
     * @return 执行结果
     */
    int updateAgentInfo(LiveAgentInfoUpdateParam param);

    /**
     * 批量更新代理人信息
     *
     * @param params 更新参数
     * @return 执行结果
     */
    int batchUpdateAgentInfo(List<LiveAgentInfoUpdateParam> params);
}
